from gdtest_code_cells import multiply
result = multiply(4, 5)
print(f"4 x 5 = {result}")multiply()
Multiply two numbers.
Usage
multiply(
a,
b,
)This function uses an executable code cell with #| eval: false so the code is displayed but not run.
Parameters
a: int-
First number.
b: int-
Second number.
Returns
int-
The product of a and b.